# Helpful Helper
Created by me, this package contains our team's most commonly used and useful functions

# About
Contents include functions for connecting to redshift. For help with what functions are available, please run help()

# Installation
To install functional-functions, you can install it using pip:
````python
pip install helpful-helper
````

# Additional Prequisites